@@ -263,20 +263,23 @@ class Tio2Jira:
             else:
                 oper = '~'
 
-            value = vuln.get(f.get(fid))
-            if f.get('is_platform_id'):
+            if f.get('static_value'):
+                value = f.get('static_value')
+            elif f.get('is_platform_id'):
                 _, value = self._get_platform()
-            if f.get('is_tio_tags') and fid == 'tio_field':
+            elif f.get('is_tio_tags') and fid == 'tio_field':
                 value = vuln.get('asset.tags')
+            else:
+                value = vuln.get(f.get(fid))
 
             # Here we will be setting the severity priority for the task and
             # subtask.
-            if f['jira_field'] == 'Finding Severity':
+            if sevprio and f['jira_field'] == 'Finding Severity':
                 subissue['priority'] = {
                     'id': str(sevprio.get(value.lower(), 4))
                 }
                 self._log.debug(f'Setting Finding Sev to {value.lower()}')
-            if f['jira_field'] == 'Vulnerability Severity':
+            if sevprio and f['jira_field'] == 'Vulnerability Severity':
                 issue['priority'] = {
                     'id': str(sevprio.get(value.lower(), 4))
                 }
